from __future__ import annotations


AQUALINK_API_KEY = "EOOEMOW4YR6QNB07"

AQUALINK_LOGIN_URL = "https://prod.zodiac-io.com/users/v1/login"
AQUALINK_DEVICES_URL = "https://r-api.iaqualink.net/devices.json"
AQUALINK_SESSION_URL = "https://p-api.iaqualink.net/v1/mobile/session.json"

AQUALINK_TEMP_CELSIUS_LOW = 1
AQUALINK_TEMP_CELSIUS_HIGH = 40
AQUALINK_TEMP_FAHRENHEIT_LOW = 32
AQUALINK_TEMP_FAHRENHEIT_HIGH = 104
